@@ -38,16 +38,19 @@ my %license_table = (
     'jpoelen'       => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV', 'CCBYSA4' ],
     'jriddell'      => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV', 'CCBYSA4' ],
     'kleag'         => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', 'CCBYSA4' ],
+    'lnj'           => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV', 'CCBYSA4' ],
     'ltoscano'      => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV', 'CCBYSA4' ],
     'lueck'         => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV', 'CCBYSA4' ],
     'michelh'       => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV', 'CCBYSA4' ],
     'muhlenpfordt'  => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV', 'CCBYSA4' ],
     'ngraham'       => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV', 'CCBYSA4' ],
     'notmart'       => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV', 'CCBYSA4' ],
+    'ostroffjh'     => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV', 'CCBYSA4' ],
     'rkflx'         => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV', 'CCBYSA4' ],
     'safaalfulaij'  => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV', 'CCBYSA4' ],
     'sitter'        => ['CCBYSA4'],
-    'sstjames'      => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV', 'CCBYSA4' ]
+    'sstjames'      => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV', 'CCBYSA4' ],
+    'thomassc'      => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV', 'CCBYSA4' ]
 );
 
 my %old_license_table_2 = (
@@ -168,7 +171,7 @@ my %old_license_table_2 = (
     'kfunk'         => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'kloecker'      => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+'        ],
     'knight'        => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
-    'knauss'        => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+ev' ],
+    'knauss'        => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'kossebau'      => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'kylafas'       => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'lbeltrame'     => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
@@ -398,10 +401,12 @@ my %secondary_mail_addresses = (
     'kubito@gmail.com' => 'rkcosta',
     'lamarque@gmail.com' => 'lvsouza',
     'malte@kde.org' => 'malte',
+    'mk-lists@email.de' => 'kaning',
     'neoclust.kde@free.fr' => 'nlecureuil',
     'olav@vitters.nl' => 'vitters',
     'richard@goteborg.utfors.se' => 'larkang',
     'sune@vuorela.dk' => 'sune',
+    'thb@net-bembel.de' => 'tbaumgart',
     'trev@adblockplus.org' => 'palant',
     'tsdgeos@terra.es' => 'aacid',
 );
@@ -409,6 +414,7 @@ my %secondary_mail_addresses = (
 my %ruletable;
 my %blacklist;
 my %whitelist;
+my %unknown_authors;
 my @blacklist_revs;
 
 foreach my $who (keys %old_license_table) {
@@ -482,7 +488,7 @@ sub resolveEmail($) {
         $resolved = $secondary_mail_addresses{$email};
     }
     if (not defined $resolved) {
-        die "Could not find $email in $accountfile\n";
+        $unknown_authors{$email} = 1;
         return $email;
     }
     return $resolved;
@@ -633,6 +639,14 @@ if (-f $file) {
     }
 }
 
+if (%unknown_authors) {
+    print "The following emails do not appear in the accounts file:\n\n";
+    foreach my $who(keys %unknown_authors) {
+        print "$who\n";
+    }
+    print "\n";
+}
+
 if (defined (keys %blacklist)) {
     print "Need permission for licensing:\n\n";
 
